"""contains some default parameters of the application."""

SMARTPHONE_ID = "pymultiMATIC"
"""Default smartphone id."""
